@@ -14,6 +14,16 @@
 #include <QTest>
 QTEST_MAIN(TimesInIntervalTest)
 
+// Copied from void RecurTodoTest::setTimeZone(const char *zonename)
+static void setTimeZone(const char *zonename)
+{
+    QVERIFY(QTimeZone(zonename).isValid());
+    qputenv("TZ", zonename);
+    const QDateTime currentDateTime = QDateTime::currentDateTime();
+    QVERIFY(currentDateTime.timeZone().isValid());
+    QCOMPARE(currentDateTime.timeZoneAbbreviation(), QString::fromLatin1(zonename));
+}
+
 using namespace KCalendarCore;
 
 void TimesInIntervalTest::test()
@@ -75,8 +85,8 @@ void TimesInIntervalTest::test()
 // Test that interval start and end are inclusive
 void TimesInIntervalTest::testSubDailyRecurrenceIntervalInclusive()
 {
-    const QDateTime start(QDate(2013, 03, 10), QTime(10, 0, 0), Qt::UTC);
-    const QDateTime end(QDate(2013, 03, 10), QTime(11, 0, 0), Qt::UTC);
+    const QDateTime start(QDate(2013, 03, 10), QTime(10, 0, 0), QTimeZone::UTC);
+    const QDateTime end(QDate(2013, 03, 10), QTime(11, 0, 0), QTimeZone::UTC);
 
     KCalendarCore::Event::Ptr event(new KCalendarCore::Event());
     event->setUid(QStringLiteral("event"));
@@ -97,8 +107,8 @@ void TimesInIntervalTest::testSubDailyRecurrenceIntervalInclusive()
 // Test that the recurrence dtStart is used for calculation and not the interval start date
 void TimesInIntervalTest::testSubDailyRecurrence2()
 {
-    const QDateTime start(QDate(2013, 03, 10), QTime(10, 2, 3), Qt::UTC);
-    const QDateTime end(QDate(2013, 03, 10), QTime(13, 4, 5), Qt::UTC);
+    const QDateTime start(QDate(2013, 03, 10), QTime(10, 2, 3), QTimeZone::UTC);
+    const QDateTime end(QDate(2013, 03, 10), QTime(13, 4, 5), QTimeZone::UTC);
 
     KCalendarCore::Event::Ptr event(new KCalendarCore::Event());
     event->setUid(QStringLiteral("event"));
@@ -120,8 +130,8 @@ void TimesInIntervalTest::testSubDailyRecurrence2()
 
 void TimesInIntervalTest::testSubDailyRecurrenceIntervalLimits()
 {
-    const QDateTime start(QDate(2013, 03, 10), QTime(10, 2, 3), Qt::UTC);
-    const QDateTime end(QDate(2013, 03, 10), QTime(12, 2, 3), Qt::UTC);
+    const QDateTime start(QDate(2013, 03, 10), QTime(10, 2, 3), QTimeZone::UTC);
+    const QDateTime end(QDate(2013, 03, 10), QTime(12, 2, 3), QTimeZone::UTC);
 
     KCalendarCore::Event::Ptr event(new KCalendarCore::Event());
     event->setUid(QStringLiteral("event"));
@@ -141,11 +151,13 @@ void TimesInIntervalTest::testSubDailyRecurrenceIntervalLimits()
 
 void TimesInIntervalTest::testLocalTimeHandlingNonAllDay()
 {
+    setTimeZone("UTC"); // Because if it isn't set, LocalTime will be different from systemTimeZone()
+
     // Create an event which occurs every weekday of every week,
     // starting from Friday the 11th of October, from 12 pm until 1 pm, clock time,
     // and lasts for two weeks, with three exception datetimes,
     // (only two of which will apply).
-    const QDateTime startDt(QDate(2019, 10, 11), QTime(12, 0), Qt::LocalTime);
+    const QDateTime startDt(QDate(2019, 10, 11), QTime(12, 0), QTimeZone::LocalTime);
     QTimeZone anotherZone("America/Toronto");
     if (anotherZone.offsetFromUtc(startDt) == QTimeZone::systemTimeZone().offsetFromUtc(startDt)) {
         anotherZone = QTimeZone(QByteArray("Pacific/Midway"));
@@ -168,7 +180,7 @@ void TimesInIntervalTest::testLocalTimeHandlingNonAllDay()
     Recurrence *recurrence = event.recurrence();
     recurrence->addRRule(rule);
     // 12 o'clock in local time, will apply.
-    recurrence->addExDateTime(QDateTime(QDate(2019, 10, 15), QTime(12, 0), Qt::LocalTime));
+    recurrence->addExDateTime(QDateTime(QDate(2019, 10, 15), QTime(12, 0), QTimeZone::LocalTime));
     // 12 o'clock in another time zone, will not apply.
     recurrence->addExDateTime(QDateTime(QDate(2019, 10, 17), QTime(12, 0), anotherZone));
     // The time in another time zone, corresponding to 12 o'clock in the system time zone, will apply.
@@ -182,7 +194,7 @@ void TimesInIntervalTest::testLocalTimeHandlingNonAllDay()
     // nor either of the exception date times.
     const QList<int> expectedDays{11, 14, 16, 17, 18, 21, 22, 23, 25};
     for (int day : expectedDays) {
-        QVERIFY(timesInInterval.contains(QDateTime(QDate(2019, 10, day), QTime(12, 0), Qt::LocalTime)));
+        QVERIFY(timesInInterval.contains(QDateTime(QDate(2019, 10, day), QTime(12, 0), QTimeZone::LocalTime)));
     }
     QCOMPARE(timesInInterval.size(), expectedDays.size());
 }
@@ -240,7 +252,7 @@ void TimesInIntervalTest::testLocalTimeHandlingAllDay()
 void TimesInIntervalTest::testByDayRecurrence()
 {
     const int days = 7;
-    const QDateTime start(QDate(2020, 11, 6), QTime(2, 0, 0), Qt::UTC);
+    const QDateTime start(QDate(2020, 11, 6), QTime(2, 0, 0), QTimeZone::UTC);
     const QDateTime intervalEnd = start.addDays(days);
     const QDateTime intervalStart = start.addDays(-days);
 
@@ -276,3 +288,33 @@ void TimesInIntervalTest::testByDayRecurrence()
 
     QCOMPARE(expectedEventOccurrences.size(), 0);
 }
+
+void TimesInIntervalTest::testRDatePeriod()
+{
+    const QDateTime start(QDate(2021, 8, 30), QTime(11, 14));
+    const QDateTime end(QDate(2021, 8, 30), QTime(11, 42));
+    const QDateTime other(QDate(2021, 8, 30), QTime(12, 00));
+    const QDateTime later(QDate(2021, 8, 30), QTime(15, 00));
+    Recurrence recur;
+
+    QVERIFY(!recur.recurs());
+    QVERIFY(!recur.rDateTimePeriod(start).isValid());
+
+    recur.addRDateTimePeriod(Period(start, end));
+    QVERIFY(recur.recurs());
+    QCOMPARE(recur.rDateTimePeriod(start), Period(start, end));
+
+    const QList<QDateTime> timesInInterval = recur.timesInInterval(start.addDays(-1),
+                                                                   start.addDays(+1));
+    QCOMPARE(timesInInterval, QList<QDateTime>() << start);
+
+    recur.addRDateTime(other);
+    QCOMPARE(recur.rDateTimes(), QList<QDateTime>() << start << other);
+    QCOMPARE(recur.rDateTimePeriod(start), Period(start, end));
+
+    recur.setRDateTimes(QList<QDateTime>() << other << later);
+    QCOMPARE(recur.rDateTimes(), QList<QDateTime>() << other << later);
+    QVERIFY(!recur.rDateTimePeriod(start).isValid());
+}
+
+#include "moc_testtimesininterval.cpp"
